MatchMakerActivation.on_first_show() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerActivation.on_first_show()

MatchMakerActivation.on_first_show()

  Executed once, when the page is shown for the first time, before executing `on_each_show()`.

  This is your go-to-hook, if you want to have access to data from other pages within the experiment, and your code is meant to be executed only once (i.e. the first time a page is shown).

  See also

  See “How to use hooks” for a how to on using hooks and an overview of available hooks.